/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.sample.internal

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentManager
import com.kakao.sdk.partner.sample.R

open class HostFragment : Fragment() {
    private lateinit var fragment: Fragment

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        super.onCreateView(inflater, container, savedInstanceState)
        return inflater.inflate(R.layout.fragment_host, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        if (this::fragment.isInitialized) {
            replaceFragment(fragment, false)
        }
    }

    override fun setMenuVisibility(menuVisible: Boolean) {
        super.setMenuVisibility(menuVisible)
        fragment.setMenuVisibility(menuVisible)

        if (isAdded) {
            childFragmentManager.fragments.map { it.setMenuVisibility(menuVisible) }
        }
    }

    fun replaceFragment(fragment: Fragment, addToBackStack: Boolean) {
        val transaction =
            childFragmentManager.beginTransaction().replace(R.id.hosted_fragment, fragment)
        if (addToBackStack) {
            transaction.addToBackStack(null)
        }
        transaction.commit()
    }

    fun onBackPressed(): Boolean {
        val fm = childFragmentManager
        if (handleBackPressed(fm)) {
            return true
        } else if (isResumed && fm.backStackEntryCount > 0) {
            fm.popBackStackImmediate()
            return true
        }
        return false
    }

//    override fun setUserVisibleHint(isVisibleToUser: Boolean) {
//        fragment.userVisibleHint = isVisibleToUser
//        if (activity != null) {
//            if (title != null) {
//                (activity as MainActivity).updateTitle(title!!)
//            }
//            if (childFragmentManager.backStackEntryCount == 0) {
//                (activity as MainActivity).hideUpButton()
//            } else {
//                (activity as MainActivity).showUpButton()
//            }
//        }
//        super.setUserVisibleHint(isVisibleToUser)
//    }

    var title: String? = null
        set(value) {
//            if (value != null && activity != null) {
//                (activity as MainActivity).updateTitle(value)
//            }
            field = value
        }

    companion object {
        @JvmStatic
        fun newInstance(fragment: Fragment, title: String): HostFragment {
            val hostFragment = HostFragment()
            hostFragment.fragment = fragment
            hostFragment.title = title
            return hostFragment
        }

        fun handleBackPressed(fm: FragmentManager): Boolean {
            for (frag in fm.fragments) {
                if (frag.isResumed && frag is HostFragment) {
                    return frag.onBackPressed()
                }
            }
            return false
        }
    }
}